#ifndef NT2_INCLUDE_FUNCTIONS_COMPARE_EQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COMPARE_EQUAL_HPP_INCLUDED

#include <nt2/reduction/include/functions/compare_equal.hpp>

#endif
